# NearBeach
![GitHub](https://img.shields.io/github/license/robotichead/NearBeach.svg)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/robotichead/NearBeach.svg)
[![CircleCI](https://circleci.com/gh/robotichead/NearBeach.svg?style=shield)](https://circleci.com/gh/robotichead/NearBeach)
[![PyPI version](https://badge.fury.io/py/NearBeach.svg)](https://badge.fury.io/py/NearBeach)
![PyPI - Downloads](https://img.shields.io/pypi/dm/NearBeach.svg?style=flat-square)
![GitHub stars](https://img.shields.io/github/stars/robotichead/NearBeach.svg?style=social)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/robotichead/NearBeach.svg)
![Liberapay receiving](https://img.shields.io/liberapay/receives/robotichead.svg)
![Website](https://img.shields.io/website/https/nearbeach.org.svg)
![Twitter Follow](https://img.shields.io/twitter/follow/robotichead.svg?style=social)


NearBeach is currently in beta development. If you find any issues, or require any help, please do not hesitate to 
contact on our forums. https://help.nearbeach.org

## What is NearBeach?

NearBeach is an open source project management system, built using Django and VueJS. The phillosophy of NearBeach is to be easy to install and use, be open sourced, and to be flexible. NearBeach is currently aimed at small/personal organisation to large enterprises. Each new module brought to NearBeach expands it's capability tenfold and brings it closer to a competing product.


## Helpful links

- [NearBeach forum](https://help.nearbeach.org)
- [Documentation](https://nearbeach.readthedocs.io)
- [Bugzilla](https://bugzilla.nearbeach.org)
- [NearBeach Homepage](https://nearbeach.org)
- [NearBeach Demo](https://demo.nearbeach.org)


## Features
NearBeach is currently going through a massive rewrite - we have stripped out a lot of the features temporarily. We are however writting them back in. Our focus of the rewrite is to improve UI/UX, and the speed of page rendering.

## Software References (thank you)

NearBeach will not be where it currently is without the help of other open sourced projects. Below are the references to all the different tools that are utilised within NearBeach. NearBeach would like to thank these projects as they have help construct a better and more stable product. Please consider visiting and donating.

### Browser Stack
Thank you to [Browser Stack](http://browserstack.com/) for giving us the ability to test NearBeach on all browsers and devices.
[![Browser Stack](https://raw.githubusercontent.com/robotichead/Store_Github_Pictures/master/browserstack-logo-600x315.png)](http://browserstack.com/)


### Snyk.io for security checks 

Python Modules - [![Known Vulnerabilities](https://snyk.io/test/github/robotichead/NearBeach/badge.svg?targetFile=NearBeach/requirements.txt)](https://snyk.io/test/github/robotichead/NearBeach?targetFile=NearBeach/requirements.txt)

JavaScript Modules - [![Known Vulnerabilities](https://snyk.io/test/github/robotichead/NearBeach/badge.svg?targetFile=package.json)](https://snyk.io/test/github/robotichead/NearBeach?targetFile=package.json)


### VueJS
Creator(s): Evan You

Github: https://github.com/vuejs/vue

License: The MIT License (MIT)

Note: VueJS is used to render all front-end UI.


### TinyMCE
Creator(s):  Tiny Technologies Inc.

Github: https://github.com/tinymce/tinymce

License: GNU Lesser General Public License v2.1

Note: TinyMCE is used for rich text within NearBeach


### Geolocation - Python
Creator(s): Sławomir Kabik

Github: https://github.com/slawek87/geolocation-python

License: BSD 3-Clause

Note: Geolocation-Python is used to contact both Google Maps and Mapbox's API.



### Weasy Print
Creator(s): Kozea 

Website: https://weasyprint.org/

Github: https://github.com/Kozea/WeasyPrint

License: BSD 3-Clause

Note: Weasy print is used to render PDF's in NearBeach



### D3.js (Data-Driven Documents)
Creator(s): Mike Bostock, Jason Davies, Jeffrey Heer, Vadim Ogievetsky

Website: https://d3js.org/

Github: https://github.com/d3/d3

License: BSD 3-Clause

Note: D3 is used for producing graphical representatives of data for NearBeach


### Bootstrap
Creator(s): Mark Otto, Jacob Thornton

Github: https://github.com/twbs/bootstrap

License: MIT

Note: NearBeach's CSS is currently being migrated to Bootstrap. For easy development.



### Feather Icons
Creator(s): Carmelo Pullara, Cole Bemis, Oliver Dumoulin

Github: https://github.com/feathericons/feather

License: MIT

Note: Feather icons are icons being utilised by NearBeach


### Vuelidate
Creator(s): Damian Dulisz, Natalia Tepluhina, Dobromir Hristov, Marina Mosti

Github: https://github.com/vuelidate/vuelidate

License: MIT

Note: We use Vuelidate for validating the form fields before submitting.
